Struct frame::arithmetic::FixedU64
pub struct FixedU64(_);Expand description
A fixed point number representation in the range. Fixed Point 64 bits unsigned, range = [0.000000000, 18446744073.709551615]
Implementations
impl FixedU64
impl FixedU64
pub const fn from_inner(inner: u64) -> FixedU64
pub const fn from_inner(inner: u64) -> FixedU64
Create a new instance from the given inner value.
const version of FixedPointNumber::from_inner.
pub const fn into_inner(self) -> u64
pub const fn into_inner(self) -> u64
Return the instance’s inner value.
const version of FixedPointNumber::into_inner.
pub const fn from_u32(n: u32) -> FixedU64
pub const fn from_u32(n: u32) -> FixedU64
Creates self from a u32.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub fn from_float(x: f64) -> FixedU64
pub fn from_float(x: f64) -> FixedU64
Convert from a float value.
pub const fn from_perbill(n: Perbill) -> FixedU64
pub const fn from_perbill(n: Perbill) -> FixedU64
Convert from a Perbill value.
pub const fn into_perbill(self) -> Perbill
pub const fn into_perbill(self) -> Perbill
Convert into a Perbill value. Will saturate if above one or below zero.
pub fn try_into_perthing<P>(self) -> Result<P, P>where
P: PerThing,
pub fn try_into_perthing<P>(self) -> Result<P, P>where P: PerThing,
Attempt to convert into a PerThing. This will succeed iff self is at least zero
and at most one. If it is out of bounds, it will result in an error returning the
clamped value.
pub fn into_clamped_perthing<P>(self) -> Pwhere
P: PerThing,
pub fn into_clamped_perthing<P>(self) -> Pwhere P: PerThing,
Attempt to convert into a PerThing. This will always succeed resulting in a
clamped value if self is less than zero or greater than one.
pub const fn neg(self) -> FixedU64
pub const fn neg(self) -> FixedU64
Negate the value.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn sqrt(self) -> FixedU64
pub const fn sqrt(self) -> FixedU64
Take the square root of a positive value.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn try_sqrt(self) -> Option<FixedU64>
pub const fn try_sqrt(self) -> Option<FixedU64>
Compute the square root, rounding as desired. If it overflows or is negative, then
None is returned.
pub const fn add(self, rhs: FixedU64) -> FixedU64
pub const fn add(self, rhs: FixedU64) -> FixedU64
Add a value and return the result.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn sub(self, rhs: FixedU64) -> FixedU64
pub const fn sub(self, rhs: FixedU64) -> FixedU64
Subtract a value and return the result.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn mul(self, rhs: FixedU64) -> FixedU64
pub const fn mul(self, rhs: FixedU64) -> FixedU64
Multiply by a value and return the result.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn div(self, rhs: FixedU64) -> FixedU64
pub const fn div(self, rhs: FixedU64) -> FixedU64
Divide by a value and return the result.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn from_rational(a: u128, b: u128) -> FixedU64
pub const fn from_rational(a: u128, b: u128) -> FixedU64
Calculate an approximation of a rational.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn from_rational_with_rounding(
a: u128,
b: u128,
rounding: Rounding
) -> FixedU64
pub const fn from_rational_with_rounding( a: u128, b: u128, rounding: Rounding ) -> FixedU64
Calculate an approximation of a rational with custom rounding.
WARNING: This is a const function designed for convenient use at build time and
will panic on overflow. Ensure that any inputs are sensible.
pub const fn const_checked_mul(self, other: FixedU64) -> Option<FixedU64>
pub const fn const_checked_mul(self, other: FixedU64) -> Option<FixedU64>
Multiply by another value, returning None in the case of an error.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
pub const fn const_checked_mul_with_rounding(
self,
other: FixedU64,
rounding: SignedRounding
) -> Option<FixedU64>
pub const fn const_checked_mul_with_rounding( self, other: FixedU64, rounding: SignedRounding ) -> Option<FixedU64>
Multiply by another value with custom rounding, returning None in the case of an
error.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
pub const fn const_checked_div(self, other: FixedU64) -> Option<FixedU64>
pub const fn const_checked_div(self, other: FixedU64) -> Option<FixedU64>
Divide by another value, returning None in the case of an error.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.
pub const fn checked_rounding_div(
self,
other: FixedU64,
rounding: SignedRounding
) -> Option<FixedU64>
pub const fn checked_rounding_div( self, other: FixedU64, rounding: SignedRounding ) -> Option<FixedU64>
Divide by another value with custom rounding, returning None in the case of an
error.
Result will be rounded to the nearest representable value, rounding down if it is equidistant between two neighbours.