Struct frame::arithmetic::RationalInfinite
pub struct RationalInfinite(_, _);Expand description
A wrapper for any rational number with infinitely large numerator and denominator.
This type exists to facilitate cmp operation
on values like a/b < c/d where a, b, c, d are all BigUint.
Implementations
impl RationalInfinite
impl RationalInfinite
pub fn from(n: BigUint, d: BigUint) -> RationalInfinite
pub fn from(n: BigUint, d: BigUint) -> RationalInfinite
Build from a raw n/d.
pub fn zero() -> RationalInfinite
pub fn zero() -> RationalInfinite
Zero.
pub fn one() -> RationalInfinite
pub fn one() -> RationalInfinite
One.